@@ -29,7 +29,7 @@ import (
 )
 
 const (
-	version             = "0.4.4"
+	version             = "0.4.5"
 	nsBOSH              = "urn:xmpp:alt-connections:xbosh"
 	nsC2SdTLS           = "urn:xmpp:alt-connections:tls"
 	nsC2SQuic           = "urn:xmpp:alt-connections:quic"
@@ -544,7 +544,6 @@ func checkHostmeta(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 	if c2s && err == nil {
 		resp, err := httpClient.Get("https://" + server + "/.well-known/host-meta")
 		if err != nil {
-			fmt.Printf("\nHost-meta: failed to request host-meta file: %v\n", err)
 			return
 		}
 		if resp.StatusCode == 404 {
@@ -581,6 +580,15 @@ func checkHostmeta(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 					checkBOSH(server, link.Href, ipv4, ipv6, tlsConfig,
 						dnsConfig, timeout)
 				}
+			default:
+				if isKnownLinkRel(link.Rel) {
+					continue
+				}
+				if !headlineShown {
+					fmt.Println("\nHost-meta:")
+					headlineShown = true
+				}
+				fmt.Printf("Unknown connection method: %s\n", link.Rel)
 			}
 		}
 	}
@@ -612,7 +620,6 @@ func checkHostmeta2(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 	}
 	resp, err := httpClient.Get("https://" + server + "/.well-known/host-meta.json")
 	if err != nil {
-		fmt.Printf("Host-meta2: failed to request host-meta file: %v\n", err)
 		return
 	}
 	if resp.StatusCode == 404 {
@@ -706,6 +713,10 @@ func checkHostmeta2(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 				}
 			case nsS2SdTLS:
 				if s2s {
+					if !headlineShown {
+						fmt.Println("\nHost-meta2:")
+						headlineShown = true
+					}
 					fmt.Printf("xmpps-server %s %d\n", link.Sni, link.Port)
 					fmt.Printf("Priority: %d Weight %d\n", link.Priority, link.Weight)
 					if verbose {
@@ -739,6 +750,10 @@ func checkHostmeta2(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 				}
 			case nsC2SQuic:
 				if c2s {
+					if !headlineShown {
+						fmt.Println("\nHost-meta2:")
+						headlineShown = true
+					}
 					fmt.Printf("C2S QUIC: %s %d\n", link.Sni, link.Port)
 					if verbose {
 						for _, ip := range link.Ips {
@@ -760,6 +775,10 @@ func checkHostmeta2(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 				}
 			case nsS2SQuic:
 				if s2s {
+					if !headlineShown {
+						fmt.Println("\nHost-meta2:")
+						headlineShown = true
+					}
 					fmt.Printf("S2S QUIC: %s %d\n", link.Sni, link.Port)
 					if verbose {
 						for _, ip := range link.Ips {
@@ -780,7 +799,14 @@ func checkHostmeta2(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 					}
 				}
 			default:
-				fmt.Printf("Unknown connection method:%s\n", link.Rel)
+				if isKnownLinkRel(link.Rel) {
+					continue
+				}
+				if !headlineShown {
+					fmt.Println("\nHost-meta2:")
+					headlineShown = true
+				}
+				fmt.Printf("Unknown connection method: %s\n", link.Rel)
 			}
 		}
 	}
